aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/sound
diff options
context:
space:
mode:
authorChristos Margiolis <christos@FreeBSD.org>2026-01-02 16:56:27 +0000
committerChristos Margiolis <christos@FreeBSD.org>2026-01-02 16:58:05 +0000
commitd6121f7b508bf889359e116da1efab08f848e129 (patch)
tree8b958f2ee0a121e95419c219a19a10cd6a601251 /sys/dev/sound
parentd2baf9301be3093c5f53a7ce1de858a0c690cd07 (diff)
Diffstat (limited to 'sys/dev/sound')
-rw-r--r--sys/dev/sound/midi/midi.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/dev/sound/midi/midi.c b/sys/dev/sound/midi/midi.c
index f54b95daf280..c658c8001b94 100644
--- a/sys/dev/sound/midi/midi.c
+++ b/sys/dev/sound/midi/midi.c
@@ -93,7 +93,7 @@ static struct cdevsw midi_cdevsw = {
.d_write = midi_write,
.d_ioctl = midi_ioctl,
.d_poll = midi_poll,
- .d_name = "rmidi",
+ .d_name = "midi",
};
struct unrhdr *dev_unr = NULL;
@@ -109,7 +109,7 @@ SYSCTL_INT(_hw_midi, OID_AUTO, debug, CTLFLAG_RW, &midi_debug, 0, "");
#define MIDI_DEBUG(l,a) if(midi_debug>=l) a
/*
* Register a new rmidi device.
*
* "cookie" is passed to the MPU calls, and is normally set to the driver's
* softc.
@@ -109,7 +109,7 @@ SYSCTL_INT(_hw_midi, OID_AUTO, debug, CTLFLAG_RW, &midi_debug, 0, "");
#define MIDI_DEBUG(l,a) if(midi_debug>=l) a
/*
- * Register a new rmidi device.
+ * Register a new midi device.
*
* "cookie" is passed to the MPU calls, and is normally set to the driver's